@@ -23,6 +23,7 @@
 
 #include "indexingqueue.h"
 #include <KJob>
+#include <QtCore/QStack>
 
 namespace Nepomuk2 {
 
@@ -105,8 +106,8 @@ namespace Nepomuk2 {
          */
         bool process(const QString& path, Nepomuk2::UpdateDirFlags flags);
 
-        QQueue< QPair<QString, UpdateDirFlags> > m_paths;
-        QQueue< QPair<QDirIterator*, UpdateDirFlags> > m_iterators;
+        QStack< QPair<QString, UpdateDirFlags> > m_paths;
+        QStack< QPair<QDirIterator*, UpdateDirFlags> > m_iterators;
 
         QUrl m_currentUrl;
         QString m_currentMimeType;
