@@ -24,20 +24,26 @@
 #include "../util.h"
 #include "../../../servicestub/priority.h"
 #include "nepomukversion.h"
+#include "nie.h"
+#include "simpleresourcegraph.h"
 
 #include <KAboutData>
 #include <KCmdLineArgs>
 #include <KLocale>
 #include <KComponentData>
+#include <KApplication>
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
 #include <QtCore/QTextStream>
 
+#include <iostream>
 #include <KDebug>
 #include <KUrl>
 #include <KJob>
 
+using namespace Nepomuk2::Vocabulary;
+
 int main(int argc, char *argv[])
 {
     lowerIOPriority();
@@ -57,14 +63,16 @@ int main(int argc, char *argv[])
     KCmdLineOptions options;
     options.add("+[url]", ki18n("The URL of the file to be indexed"));
     options.add("clear", ki18n("Remove all indexed data of the URL provided"));
-    options.add("debug", ki18n("First clears the existing index, and then runs both the basic and file indexing"));
+    options.add("data", ki18n("Streams the indexed data to stdout"));
 
     KCmdLineArgs::addCmdLineOptions(options);
     const KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     // Application
-    QCoreApplication app( argc, argv );
-    KComponentData data( aboutData, KComponentData::RegisterAsMainComponent );
+    // Use KApplication instead of QCoreApplication since the okular plugin expects a running GUI
+    KApplication app;
+//    QCoreApplication app( argc, argv );
+//    KComponentData data( aboutData, KComponentData::RegisterAsMainComponent );
 
     if( args->count() == 0 ) {
         QTextStream err( stderr );
@@ -85,14 +93,19 @@ int main(int argc, char *argv[])
     }
 
     Nepomuk2::Indexer indexer;
-    // Debugging
-    if( args->isSet("debug") ) {
-        if( !indexer.indexFileDebug( args->url(0) ) ) {
-            QTextStream s(stdout);
-            s << indexer.lastError();
 
-            return 1;
-        }
+    if( args->isSet("data") ) {
+        Nepomuk2::SimpleResourceGraph graph = indexer.indexFileGraph( args->url(0) );
+
+        // Optimization, in this case we generally don't care about the plain text content
+        graph.removeAll( QUrl(), NIE::plainTextContent() );
+
+        QByteArray byteArray;
+        QDataStream s(&byteArray, QIODevice::WriteOnly);
+        s << graph;
+
+        std::cout << byteArray.toBase64().constData();
+
         return 0;
     }
 
