@@ -96,6 +96,7 @@ Nepomuk2::IndexScheduler::IndexScheduler( QObject* parent )
     connect( m_fileIQ, SIGNAL(endIndexingFile(QUrl)), this, SIGNAL(statusStringChanged()) );
     connect( m_fileIQ, SIGNAL(startedIndexing()), this, SIGNAL(statusStringChanged()) );
     connect( m_fileIQ, SIGNAL(finishedIndexing()), this, SIGNAL(statusStringChanged()) );
+    connect( this, SIGNAL(indexingSuspended(bool)), this, SIGNAL(statusStringChanged()) );
 
     m_eventMonitor = new EventMonitor( this );
     connect( m_eventMonitor, SIGNAL(diskSpaceStatusChanged(bool)),
@@ -174,6 +175,11 @@ bool Nepomuk2::IndexScheduler::isSuspended() const
     return m_state == State_Suspended;
 }
 
+bool Nepomuk2::IndexScheduler::isCleaning() const
+{
+    return m_state == State_Cleaning;
+}
+
 bool Nepomuk2::IndexScheduler::isIndexing() const
 {
     return m_indexing;
